@@ -43,6 +43,10 @@ mod tests {
     这种非String类型的不会格式化
     ```
 
+    ```md
+    ![流程图片](../../static/xxxx.png)
+    ```
+
     | 字段       | 长度(bit) | 长度（字节）| 说明                                                                       |
     | ---------- | ---------- | ------------ | -------------------------------------------------------------------------- |
     | request_id | 32(uint32) | 4            | 请求id，同一个连接的id需要唯一，从1开始，到达4294967295后从新开始。 |
@@ -79,6 +83,10 @@ mod tests {
     这种非String类型的不会格式化
     ```
 
+    ```md
+    ![流程图片](../../static/xxxx.png)
+    ```
+
     | 字段       | 长度 (bit) | 长度（字节）| 说明                                                                       |
     | ---------- | ---------- | ------------ | -------------------------------------------------------------------------- |
     | request_id | 32(uint32) | 4            | 请求 id，同一个连接的 id 需要唯一，从 1 开始，到达 4294967295 后从新开始。 |
